//
//  EulerMarker.swift
//  KLines
//
//  Created by 小生不才 on 2018/4/17.
//  Copyright © 2018年 schild. All rights reserved.
//

import Foundation
import Charts
import SwiftyJSON

open class ERCandleMarker: MarkerView {
  open var textColor: UIColor?
  open var font: UIFont?
  
  private let buyTitleColor = #colorLiteral(red: 0.8156862745, green: 0.007843137255, blue: 0.1058823529, alpha: 0.36)
  private let buyContentColor = #colorLiteral(red: 0.8156862745, green: 0.007843137255, blue: 0.1058823529, alpha: 0.64)
  private let sellTitleColor = #colorLiteral(red: 0.1882352941, green: 0.4352941176, blue: 0.8588235294, alpha: 0.8)
  private let sellContentColor = #colorLiteral(red: 0.1882352941, green: 0.4352941176, blue: 0.8588235294, alpha: 0.8)
  
  private var markerData: [String : baseLabel] = [:]
  
  private class baseLabel: UILabel {
    var style = NSMutableParagraphStyle()
    
    init(frame: CGRect, text: String, bgColor: UIColor) {
      super.init(frame: frame)
      self.style.firstLineHeadIndent = 10
      setAttrString(str: text, bgColor: bgColor)
    }
    
    required init?(coder aDecoder: NSCoder) {
      fatalError("init(coder:) has not been implemented");
    }
    
    func setAttrString(str:String, bgColor:UIColor){
      self.attributedText = NSMutableAttributedString(string: str, attributes: [
        .paragraphStyle : style,
        .font: UIFont.systemFont(ofSize: 10.0),
        .foregroundColor: #colorLiteral(red: 1.0, green: 1.0, blue: 1.0, alpha: 1.0)])
      self.backgroundColor = bgColor
    }
  }
  
  public init(font: UIFont, color: UIColor) {
    super.init(frame: CGRect.init(x: 8, y: 0, width: 120, height: 100));
    // 属性赋值
    self.font = font
    self.textColor = color
    
    // config设置
    self.backgroundColor = sellContentColor
    self.isHidden = true
    self.layer.masksToBounds = true
    self.layer.cornerRadius = 8
    
    // 初始化数据
    let initData: [String : String] = [
      "strategyName": "择优打板",
      "strategyY": "策略收益 00.0%",
      "floatWinDate": "2018-01-01 00:00",
      "tradePrice": "成交价 0.00",
      "profitLoss": "盈亏 0.00%",
      ]
    for (key, value) in initData {
      switch(key){
      case "strategyName":
        self.markerData[key] = baseLabel(frame: CGRect(x: 0, y: 0, width: 120, height: 20), text: value, bgColor: sellTitleColor)
      case "strategyY":
        self.markerData[key] = baseLabel(frame: CGRect(x: 0, y: 20, width: 120, height: 20), text: value, bgColor: sellTitleColor)
      case "floatWinDate":
        self.markerData[key] = baseLabel(frame: CGRect(x: 0, y: 40, width: 120, height: 20), text: value, bgColor: sellContentColor)
      case "tradePrice":
        self.markerData[key] = baseLabel(frame: CGRect(x: 0, y: 60, width: 120, height: 20), text: value, bgColor: sellContentColor)
      case "profitLoss":
        self.markerData[key] = baseLabel(frame: CGRect(x: 0, y: 80, width: 120, height: 20), text: value, bgColor: sellContentColor)
      default:
        fatalError("key is not support")
      }
    }
    
    // 讲子view添加进container
    self.addSubview(self.markerData["strategyName"]!)
    self.addSubview(self.markerData["strategyY"]!)
    self.addSubview(self.markerData["floatWinDate"]!)
    self.addSubview(self.markerData["tradePrice"]!)
    self.addSubview(self.markerData["profitLoss"]!)
  }
  
  public required init?(coder aDecoder: NSCoder) {
    fatalError("init(coder:) has not been implemented");
  }
  
  override open func refreshContent(entry: Charts.ChartDataEntry, highlight: Charts.Highlight){
    if let object = entry.data as? JSON {
      switch(object["action"].number){
      case 1:
        self.isHidden = false
        self.backgroundColor = buyContentColor
        self.markerData["strategyName"]!.setAttrString(
          str: object["strategyName"].string != nil ? object["strategyName"].string! : "择优打板",
          bgColor: buyTitleColor)
        self.markerData["strategyY"]!.setAttrString(
          str: object["strategyY"].number != nil ? "策略收益 " + String(format: "%.2f", object["strategyY"].number!.doubleValue) + "%" : "策略收益 0.0%",
          bgColor: buyTitleColor)
        self.markerData["floatWinDate"]!.setAttrString(
          str: object["floatWinDate"].string != nil ? object["floatWinDate"].string! : "2018-01-01 00:00",
          bgColor: #colorLiteral(red: 1, green: 1, blue: 1, alpha: 0))
        self.markerData["tradePrice"]!.setAttrString(
          str: object["tradePrice"].number != nil ? "成交价 " + String(format: "%.2f", object["tradePrice"].number!.doubleValue) : "成交价 0.00",
          bgColor: #colorLiteral(red: 1, green: 1, blue: 1, alpha: 0))
        self.markerData["profitLoss"]!.isHidden = true
      case 2:
        self.isHidden = false
        self.backgroundColor = sellContentColor
        self.markerData["strategyName"]!.setAttrString(
          str: object["strategyName"].string != nil ? object["strategyName"].string! : "择优打板",
          bgColor: sellTitleColor)
        self.markerData["strategyY"]!.setAttrString(
          str: object["strategyY"].number != nil ? "策略收益 " + String(format: "%.2f", object["strategyY"].number!.doubleValue) + "%" : "策略收益 0.0%",
          bgColor: sellTitleColor)
        self.markerData["floatWinDate"]!.setAttrString(
          str: object["floatWinDate"].string != nil ? object["floatWinDate"].string! : "2018-01-01 00:00",
          bgColor: #colorLiteral(red: 1, green: 1, blue: 1, alpha: 0))
        self.markerData["tradePrice"]!.setAttrString(
          str: object["tradePrice"].number != nil ? "成交价 " + String(format: "%.2f", object["tradePrice"].number!.doubleValue) : "成交价 0.00",
          bgColor: #colorLiteral(red: 1, green: 1, blue: 1, alpha: 0))
        self.markerData["profitLoss"]!.isHidden = false
        self.markerData["profitLoss"]!.setAttrString(
          str: object["profitLoss"].number != nil ? "盈亏 " + String(format: "%.2f", object["profitLoss"].number!.doubleValue) + "%" : "盈亏 0.00%",
          bgColor: #colorLiteral(red: 1, green: 1, blue: 1, alpha: 0))
      case 3:
        self.isHidden = true
      default :
        self.isHidden = true
      }
    }
  }
}

